
      const require = await (async () => {
        const { createRequire } = await import("node:module");
        return createRequire(import.meta.url);
      })();
    
import {
  require_out
} from "./chunk-AVWFCGVE.js";
import {
  getPrerenderManifest
} from "./chunk-FQII764Q.js";
import {
  BLOB_DIR
} from "./chunk-FSAVFRLT.js";
import {
  __toESM
} from "./chunk-RSKIKBZH.js";

// src/build/content/prerendered.ts
var import_fast_glob = __toESM(require_out(), 1);
import { existsSync } from "node:fs";
import { mkdir, readFile, writeFile } from "node:fs/promises";
import { dirname, resolve } from "node:path";
var writeCacheEntry = async (key, value) => {
  await mkdir(dirname(resolve(BLOB_DIR, key)), { recursive: true });
  await writeFile(
    resolve(BLOB_DIR, key),
    JSON.stringify({ lastModified: Date.now(), value }),
    "utf-8"
  );
};
var urlPathToFilePath = (path) => path === "/" ? "/index" : path;
var buildPagesCacheValue = async (path) => ({
  kind: "PAGE",
  html: await readFile(resolve(`${path}.html`), "utf-8"),
  pageData: JSON.parse(await readFile(resolve(`${path}.json`), "utf-8"))
});
var buildAppCacheValue = async (path) => ({
  kind: "PAGE",
  html: await readFile(resolve(`${path}.html`), "utf-8"),
  pageData: await readFile(resolve(`${path}.rsc`), "utf-8"),
  ...JSON.parse(await readFile(resolve(`${path}.meta`), "utf-8"))
});
var buildRouteCacheValue = async (path) => ({
  kind: "ROUTE",
  body: await readFile(resolve(`${path}.body`), "utf-8"),
  ...JSON.parse(await readFile(resolve(`${path}.meta`), "utf-8"))
});
var buildFetchCacheValue = async (path) => ({
  kind: "FETCH",
  ...JSON.parse(await readFile(resolve(path), "utf-8"))
});
var copyPrerenderedContent = async ({
  constants: { PUBLISH_DIR },
  utils: {
    build: { failBuild }
  }
}) => {
  try {
    const manifest = await getPrerenderManifest({ PUBLISH_DIR });
    const routes = Object.entries(manifest.routes);
    const notFoundRoute = "server/app/_not-found";
    await Promise.all(
      routes.map(async ([path, route]) => {
        let key, value;
        switch (true) {
          case route.dataRoute?.endsWith(".json"):
            key = `server/pages/${urlPathToFilePath(path)}`;
            value = await buildPagesCacheValue(resolve(PUBLISH_DIR, key));
            break;
          case route.dataRoute?.endsWith(".rsc"):
            key = `server/app/${urlPathToFilePath(path)}`;
            value = await buildAppCacheValue(resolve(PUBLISH_DIR, key));
            break;
          case route.dataRoute === null:
            key = `server/app/${urlPathToFilePath(path)}`;
            value = await buildRouteCacheValue(resolve(PUBLISH_DIR, key));
            break;
          default:
            throw new Error(`Unrecognized prerendered content: ${path}`);
        }
        await writeCacheEntry(key, value);
      })
    );
    if (existsSync(resolve(PUBLISH_DIR, `${notFoundRoute}.html`))) {
      await writeCacheEntry(
        notFoundRoute,
        await buildAppCacheValue(resolve(PUBLISH_DIR, notFoundRoute))
      );
    }
  } catch (error) {
    failBuild(
      "Failed assembling prerendered content for upload",
      error instanceof Error ? { error } : {}
    );
  }
};
var copyFetchContent = async ({
  constants: { PUBLISH_DIR },
  utils: {
    build: { failBuild }
  }
}) => {
  try {
    const paths = await (0, import_fast_glob.default)([`cache/fetch-cache/!(*.*)`], {
      cwd: resolve(PUBLISH_DIR),
      extglob: true
    });
    await Promise.all(
      paths.map(async (key) => {
        await writeCacheEntry(key, await buildFetchCacheValue(resolve(PUBLISH_DIR, key)));
      })
    );
  } catch (error) {
    failBuild("Failed assembling fetch content for upload", error instanceof Error ? { error } : {});
  }
};

export {
  copyPrerenderedContent,
  copyFetchContent
};
